Convenience functions for ANSI terminal colour sequences
--------------------------------------------------------

Mapping and function for adding ANSI terminal colour escape sequences
to strings for colour highlighting of output.
